@@ -16,7 +16,7 @@ import sys
 import time
 from datetime import datetime
 import threading
-import xmlrpc.client
+# import xmlrpc.client
 
 from pyrois import RoIS_Common, RoIS_HRI, IF_server
 
